#
# spec file for package python-jupyterlab
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define         skip_python2 1
Name:           python-jupyterlab
Version:        2.2.10
Release:        bp155.1.51
Summary:        Environment for interactive and reproducible computing
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/jupyterlab/jupyterlab
Source0:        https://files.pythonhosted.org/packages/py3/j/jupyterlab/jupyterlab-%{version}-py3-none-any.whl
Source99:       python-jupyterlab-rpmlintrc
BuildRequires:  %{python_module base >= 3.5}
BuildRequires:  %{python_module jupyterlab-server >= 1.1.5}
BuildRequires:  %{python_module notebook >= 4.3.1}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module tornado}
BuildRequires:  fdupes
BuildRequires:  jupyter-jupyterlab-filesystem
BuildRequires:  nodejs >= 10
BuildRequires:  npm >= 10
BuildRequires:  python-rpm-macros
Requires:       jupyter-jupyterlab = %{version}
Requires:       python-Jinja2 >= 2.10
Requires:       python-base >= 3.5
Requires:       python-jupyter-core
Requires:       python-jupyterlab-server >= 1.1.5
Requires:       python-notebook >= 4.3.1
Requires:       python-tornado
Provides:       python-jupyter_jupyterlab = %{version}
Obsoletes:      python-jupyter_jupyterlab < %{version}
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Jinja2 >= 2.10}
BuildRequires:  %{python_module pytest-check-links}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests}
# /SECTION
%python_subpackages

%description
An extensible environment for interactive and reproducible computing,
based on the Jupyter Notebook and Architecture.

JupyterLab is the next-generation user interface for Project Jupyter
offering all the familiar building blocks of the classic Jupyter
Notebook (notebook, terminal, text editor, file browser, rich outputs,
etc.). 

%package     -n jupyter-jupyterlab
Summary:        Environment for interactive and reproducible computing
Group:          Development/Languages/Python
Requires:       jupyter-jupyter-core
Requires:       jupyter-jupyterlab-filesystem
Requires:       jupyter-jupyterlab-server >= 1.0.0
Requires:       jupyter-notebook >= 4.3.1
Requires:       nodejs >= 10
Requires:       npm >= 10
Requires:       python3-jupyterlab = %{version}
Provides:       jupyter-jupyterlab-discovery = 6
Obsoletes:      jupyter-jupyterlab-discovery < 6

%description -n jupyter-jupyterlab
An extensible environment for interactive and reproducible computing,
based on the Jupyter Notebook and Architecture.

JupyterLab is the next-generation user interface for Project Jupyter
offering all the familiar building blocks of the classic Jupyter
Notebook (notebook, terminal, text editor, file browser, rich outputs,
etc.). 

%prep
%setup -q -c -T

%build
# not needed

%install
cp -a %{SOURCE0} .
%pyproject_install

%{jupyter_move_config}
%python_expand sed -i -e 's|^#!/usr/bin/env node|#!%{_bindir}/node|' %{buildroot}%{$python_sitelib}/jupyterlab/node-version-check.js
%python_expand sed -i -e 's|^#!/usr/bin/env node|#!%{_bindir}/node|' %{buildroot}%{$python_sitelib}/jupyterlab/staging/yarn.js
%python_expand chmod a+x %{buildroot}%{$python_sitelib}/jupyterlab/node-version-check.js
%python_expand chmod a+x %{buildroot}%{$python_sitelib}/jupyterlab/staging/yarn.js
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%fdupes %{buildroot}%{_jupyter_prefix}

cp %{buildroot}%{python3_sitelib}/jupyterlab-%{version}.dist-info/LICENSE .

%check
export PYTHONDONTWRITEBYTECODE=1
# Disable build checks that pull in remote resources with npm
%{pytest %{buildroot}%{$python_sitelib}/jupyterlab/ -k \
    'not (test_build or test_clear or test_build_check or test_build_custom or test_uninstall_core_extension or test_install_and_uninstall_pinned or test_install_and_uninstall_pinned_folder or test_install_extension)'
}

%files %{python_files}
%license %{python_sitelib}/jupyterlab-%{version}.dist-info/LICENSE
%{python_sitelib}/jupyterlab/
%{python_sitelib}/jupyterlab-%{version}.dist-info/

%files -n jupyter-jupyterlab
%license LICENSE
%{_bindir}/jlpm
%{_bindir}/jupyter-lab
%{_bindir}/jupyter-labextension
%{_bindir}/jupyter-labhub
%config %{_jupyter_servextension_confdir}/jupyterlab.json
%{_jupyter_lab_dir}

%changelog
* Thu Jul 28 2022 Steve Kowalik <steven.kowalik@suse.com>
- Update to 2.2.10:
  * Remove `form` tags' `action` attribute during sanitizing, to prevent an
    XSS (CVE-2021-32797) (bsc#1196663)
  * Header ‘Content-Type’ should not be overwritten
  * Do not use token parameters in websocket urls
  * Properly handle errors in async browser_check
  * Cells can no longer be executed while kernels are terminating or
    restarting. There is a new status for these events on the Kernel Indicator
  * Add styling for high memory usage warning in status bar with nbresuse
  * Adds support for Python version 3.10
  * Support live editing of SVG with updating rendering
  * Lazy load codemirror theme stylesheets
  * Add feature request template + slight reorg in readme
  * Add link to react example in extension-examples repo
  * Close correct tab with close tab
  * Remove unused css rules
  * Simplified multicursor backspace code
  * Fix recent breaking changes to normalizepath in filebrowser
  * Handle quit_button when launched as an extension
  * Add worker-loader
  * Fix icon sidebar height for third party extensions
  * Scrolls cells into view after deletion
  * Support Node.js 10+
  * Select search text when focusing the search overlay
  * Throttle fetch requests in the setting registry’s data connector
  * Avoid redundant checkpoint calls on loading a notebook
* Wed Apr  1 2020 Tomáš Chvátal <tchvatal@suse.com>
- We should work with tornado 4, 5 and 6.
- The bugs were found in tornado 6.0.1 and 6.0.2 were fixed
  by upstream developers
* Fri Mar  6 2020 Todd R <toddrme2178@gmail.com>
- Requires nodejs/npm >= 10
* Tue Mar  3 2020 Todd R <toddrme2178@gmail.com>
- Update to 2.0.0
  + User-facing changes
  * New user interface for notebook cell tags
  * File info display when hovering on a file in the file browser
  * Support for searching outputs in notebooks
  * ``Ctrl Shift .`` and ``Ctrl Shift ,`` shortcuts move focus to the next and previous tab bar in the main area, respectively
  * ``Shift Home`` and ``Shift End`` shortcuts in a notebook select all cells from the current cell to the top or bottom of a notebook, respectively
  * Explicit "No Kernel" button in the kernel selection dialog for new notebooks
  * Notebook ``recordTiming`` advanced setting to control whether execution timing information is stored in notebook files
  * "Select current running or last run cell" command added (requires notebook ``recordTiming`` advanced setting to be set to true)
  * Codemirror ``lineWiseCopyCut`` advanced setting to control the behavior of the copy/cut keyboard shortcuts when there is no selection
  * Refreshed the command palette and property inspector sidebar icons and user interfaces
  * "New File" and "New Markdown File" items in file browser context menu
  * "Download" item in File menu
  * "Restart Kernel and Run up to Selected Cell" item in notebook Kernel menu
  * In extension manager, the "enable" button is now only shown for installed extensions
  * Dialogs can now be closed by clicking outside of them
  * ``documentsearch:startWithReplace`` command to open the document find overlay with replace. There is not currently a default keyboard shortcut for this, but one can be assigned as a custom keyboard shortcut in Advanced Settings.
  * ``#`` added to the CSV Viewer delimiter options
  * The JSON viewer now only displays structure hints for arrays and empty objects for a more streamlined feel
  * Optional platform-aware keyboard shortcut fields ``linuxKeys``, ``macKeys``, and ``winKeys`` in keyboard shortcut definitions
  * Added options for ``jupyter lab clean`` to clean specific parts of the build, such as ``--extensions``, ``--settings``, ``--static``, and ``--all``
  * Removed the vega 4 and vega-lite 2 renderers (vega 5 and vega-lite 4 is included in JupyterLab by default). These legacy renderers may be available via custom extensions
  * JupyterHub users should use the ``c.Spawner.default_url = '/lab'`` setting instead of the deprecated and now removed ``labhubapp``
  + Backward incompatible changes
  * Switch from ``@phosphor`` to ``@lumino`` dependencies.
  * Factor out the ``settingsregistry`` and ``statedb`` packages from coreutils
  * Rework services architecture (sessions, kernels, terminals) and rename ``ClientSession`` to ``SessionContext``
  * Upgrade to TypeScript 3.7
  * Remove ``polling`` from coreutils in favor for ``@lumino/polling``
  * TypeScript strict null checking in core packages
  * Update state database list method to query based on namespace match.
  * Address code todo items and deprecations for 2.0
  * Update Console panel tracker widgets
  * Update contribution guide to require node v12+
  * New API for the ``Running`` sidebar extension
  * Clean up handling of icons under unified LabIcon
  + Other changes
  * New property inspector used to display the properties of the currently selected main area widget
  * Allow metadata for launcher items
  * Allow default file browser to restore manually.
  * Upgrade bundled yarn to 1.21.1
  * Make session dialogs configurable
  * Support transient editor configs
  * Optionally force new browser tab
  * Update core dependencies (e.g., ``codemirror``, ``xterm.js``, ``markdown``, ``fontawesome``, etc.)
  * Add storybook to ``ui-components``
  * Add explicit documentation encouraging people to re-use lab components
  * Enable TypeScript sourcemaps for debugging locally installed labextensions
  * Add ``UseSignal`` example to the docs
  * Add ``env`` prop to kernel options
  * Add kernelspec metadata
  * Allow different mimetypes for the clipboard data
  * Add password dialog to apputils
  * Alias phosphor packages to lumino to allow a deprecation period for phosphor
  * Match react version in ui-components peerdependencies
  * Fix lint-staged for both win and mac
  * Update websocket workaround for node environments
  * Fix handling of linked extensions
  * Fix extension compatibility checks for prereleases and extensions supporting multiple major versions of JupyterLab
  * Teach update-dependency about more range specifiers and make it adopt the current range for any tag
  * Add support for giving a rank to items in the top area
  * Apply all options to the initial JupyterLab application instance
  + Bugfixes
  * "Copy Shareable Link" in the file browser context menu now properly works in JupyterHub
  * Update Mathjax CDN in the cell and console examples
  * Revert ensure-max-old-space now that Node 12+ has better default memory ceilings
  * Resolve race condition between default file browser and tree urls.
  * Fix handling of code editor refresh
  * Start new notebooks in edit mode
  * Use consistent versions of React
  * Add scrollbar styles to nbconvert-css
  * Close output views when corresponding notebooks are closed
  * Fixed incorrect white background for new command palette icon
  * Block fetching the settings for a plugin that is disabled
  * When timing metadata changes, ensure signal fires
  * Prevent memory leaks in Vega renderer
  * Handle cell execution cancellation when cell is disposed
  * Fix dropdown option style issue on Windows
  * Make sure label is linked to a control when checking for element type
  * Refine log console message UX
  * Fix multicursor backspacing
  * Reset log display and count when non-notebook tab gets activated
  * Fix Safari multiple tabs by working around a Safari bug.
  * Skip custom click behavior on links when the download attribute is set
  * Fix context menu hit test to deal with SVG nodes.
  * Fix overwriting of target attribute of anchors rendered by ``IPython.display``
  * Fix file browser location in tree view
  * Stop too many fetch calls in docmanager-extension
  * Ensures that ``Shift Tab`` dedent shortcut works correctly in the file editor
  * Fix unexpected jump to last search result when using documentsearch
  * Fixed refresh issue for html viewer
  * Fix for center-aligned images with IPython.display.image
  * Changes to setting editor should trigger application dirty state
  * Move vega from "devdependencies" to "dependencies"
  * Restore default file browser manually.
  * Use default ``app_dir`` when ``app_dir`` is ``''``
* Tue Jan 28 2020 Todd R <toddrme2178@gmail.com>
- Update to 1.2.6
  * Update dependencies
* Wed Jan 15 2020 Todd R <toddrme2178@gmail.com>
- Update to 1.2.4
  * update yarn.lock
  * update terser dep
* Tue Dec 10 2019 Bernhard Wiedemann <bwiedemann@suse.com>
- Use pyproject_install macro (boo#1094323)
* Mon Dec  9 2019 Todd R <toddrme2178@gmail.com>
- Update to version 1.2.3
  * Update status bar index.css to be hand-curated
  * fix dropdown option style issue in Windows
  * Update the ui-components css to reflect the correct dependencies.
- Rename spec file to python-jupyterlab to work better
  with OSC python tooling.
* Tue Nov 12 2019 Todd R <toddrme2178@gmail.com>
- Update to version 1.2.2
  + User-facing changes
  * Select cells from the current cell to the top of the notebook with ``Shift Home``, to the bottom of the notebook with ``Shift End``
  * Add a log console extension to display unhandled messages and other activity
  * Allow the npm ``max-old-space`` option to be specified outside of JupyterLab
  * Only display node structure in a JSON tree view for arrays and empty objects
  * Make much smaller distribution packages by not building JavaScript source maps for releases.
  * Add support for pasting cell attachments and dragging attachments from the file browser
  * Add a new ``registry`` configuration parameter to override the default yarn repository when building
  + For developers
  * Update the Markdown renderer (``marked``) to 0.7.0
  * Remove datagrid as a singleton, allowing extensions to use newer versions
  * Add metadata to the kernelspec information
  * Allow different mimetypes for the clipboard data
  * Add inline svg icon support to toolbar buttons
  * Add PageConfig functions to query if a plugin is deferred or disabled
  * Allow for renderers for nbformat.ierror to be created
  * Refactor ``fileeditor-extension`` for modularization
  * Add execution timing to cells
  + Bugfixes
  * Fix the ``file-browser-path`` query parameter
  * Skip custom click behavior on links when the download attribute is set
  * Fix opening multiple browser tabs in Safari
  * Fix context menus on SVG icons
  * Fix overwriting of target attribute of anchors rendered by ``IPython.display``
  * Fix multi-cursor backspacing
  * Fix mult-cursor cell splitting
* Mon Aug 26 2019 Todd R <toddrme2178@gmail.com>
- Use better way to handle tornado version compatibility.
* Fri Aug 23 2019 Todd R <toddrme2178@gmail.com>
- Update to 1.0.9
  * integrity
  * update packages
  * fix package name
  * enforce jinja2 requirement
- jupyterlab-discovery has been merged into jupyterlab
* Tue Aug 20 2019 Todd R <toddrme2178@gmail.com>
- Update to 1.0.6
  + User Facing Changes
  * We have added first class support for find and replace across JupyterLab. It is currently supported in notebooks and text files and is extensible for other widgets who wish to support it.
  * We have integrated the JupyterLab Status Bar package into the core distribution. Extensions can add their own status to it as well.
  * We now include the JupyterHub extension in core JupyterLab, so you no longer need to install ``@jupyterlab/hub-extension``.
  * JupyterLab now has a File > Logout menu entry when running with JupyterHub
  * now have a printing system that allows extensions to customize how documents and activities are printed.
  * The launcher displays longer kernel names and supports keyboard navigation
  * Notebook outputs without any valid MimeType renderers will not be displayed, instead of displaying an error
  * Add tooltip to file browser root breadcrumb icon showing the server root, if it is available
  * Downloading a file will no longer open a new browser window
  * Rename the help "Inspector" to "Contextual Help" and move it to the "Help" menu
  * Update many of the icons to make them more consistent
  * Update the settings UI to remove the table view
  * Replace FAQ Extension with link to JupyterLab documentation
  * Change the default keyboard shortcut for closing a tab to be ``Alt+w`` instead of ``Cmd/Ctrl+w`` to avoid conflicts with operating systems.
  * Show help text in Inspector window to describe you should select a function
  * Fixes SVG rendering
  * Add support for dropping a tab in the tab bar area.
  * Switch some default shortcuts to use ``Accel`` instead of ``Ctrl`` so they are more natural for Mac users
  * Add ability to tell between hover and selected command palette items
  * Hide the "Last Modified" column when the file browser is narrow
  * Support copy/paste in terminal and Mac OS using ``Ctrl+C`` and ``Ctrl+V``
  * Support scrolling in running kernels panel
  * Adds ability to "Merge Selected Cells" in the context menu in the notebook
  * Turn On Accessibility In Xterm.js to make it more compatible for screen readers
  * When selecting cells using the keyboard shortcuts, we now skip collapsed cells
  * Supporting opening ``.geojson`` files in JSON viewer
  * Performance fixes for text-based progress bars
  * Add support for rendering Vega 5 and Vega Lite 3 while keeping the existing Vega 4 and Vega Lite 2 renderers
  * Drag and drop console cells into a notebook or text editor
  * Drag and drop notebook cells into a console or text editor
  * The extension manager search now sorts extensions by the score assigned to them by NPM instead of alphabetically
  * Notify the user when a kernel is automatically restarted, for example, if crashes from an out of memory error
  * Expose the extension manager in a command and menu item
  * Add command to render all Markdown cells
  * Supports using shift to select text in output area
  * Output areas that opened in new views are restored properly now on reload
  * Add support for managing notebook metadata under a new "Advanced Tools" section in the cell tools area. The cell and notebook metadata now always reflect the current state of the notebook
  * Inherit terminal theme from core theme
  * Adds a built-in HTML viewer so that you can view HTML files
  * New workspaces are now automatically generated when you create a new window with the same workspace name.
  * We now add a hint to the context menu to describe how you can access the native browser menu
  * The tabs on the left panel have changed to make them more understandable
  * Start a new terminal when the page is refreshed and the old terminal has died
  * Add a command to open the main menus, which can be assigned to a keyboard shortcut to open and navigate menus without a mouse
  * The contextual help now updates based on changes in the cursor from the mouse instead of just from the keyboard
  * The launcher now updates when the kernels change on the server
  * Retain cell auto scroll behavior even when a cell output is cleared
  * If you link to a relative path that is not a file in a markdown cell, this will now be preserved instead of changing it to a file URL
  * Adds the ability to link to a certain row in a CSV file and have the viewer open to that row
  * We have improved the performance of switching to a large notebook
  * The vdom extension now supports event handling, so that you can have kernel code run in response to user interaction with the UI
  * Adds the ability to run "Run All Code" and "Restart Kernel and Run All Code" in code and markdown files
  * We now remember what line ending a text file has when loading it, so that files with ``CRLF`` line endings will properly be saved with the same endings
  * Fixes rendering of SVG elements in HTML MimeType output
  * Allow copying files by holding down ``Ctrl`` when dragging them in the file browser
  * Switch the hover modified time in the file browser to use the local format
  * We have added a default keyboard shortcut of ``Ctrl Shift Q`` for closing and cleaning up a file
  * Adds the ability to find and go to a certain line in the CSV viewer
  * Add the ability to create new text and markdown files from the launcher and command palette
  * A "New Folder" option has been added to the file browser context menu
  * The ANSI colors are now the same as those in the classic notebook
  * Send complete statements instead of current lines when stepping through code in a cell
  * Description list styles (``dl``, ``dt``, ``dd``) are improved to be consistent with the nteract project
  + Settings
  * The settings system has been rewritten and now uses json5 as the syntax, which supports comments and other features for better human readability.
  * The keyboard shortcut system has been rewritten and now displays a list of system commands in the settings comments.
  * There are new settings for many following items, including:
    > Adds an option to shut down terminals and notebook kernels when they are closed
    > Scrolling past the end of a notebooks and text editor document
    > Text editor code folding, rulers, and active line highlighting
    > Markdown viewer options
    > Terminal scrollback and other settings
    > The autosave interval
    > The file browser showing the current active file
    > Custom scrollbar styling for dark themes
  + Command Line Changes
  * Installing extensions will be quieter and adds a ``--debug`` to extension installing
  * We now support running JupyterLab when its application directory is a symlink
  * Add ``--all`` flag to ``labextension uninstall`` to remove all extensions
  * Adds the ability to override the base URLs from the config
  * Updates to workspaces CLI command
  + Extension Development Changes
  * We have rewritten how extensions provide keyboard shortcuts and interact with the settings system. If you previously defined keyboard shortcuts or used the settings mechanism, you will need to update your extension
  * We have renamed the plugin type from ``JupyterLabPlugin`` to ``JupyterFrontEndPlugin``. The application arg is also renamed from ``JupyterLab`` to  ``JupyterFrontEnd`` and some its functionality has been moved to a separate ``ILabShell`` plugin
  * The lab shell ``addToMainArea``, ``addToLeftArea``, ``addToTopArea``, ``addToRightArea``, and ``addToBottomArea`` functions have been replaced with a single ``add()`` function that takes the area as an argument. Replace ``addToMainArea(widget, options)`` with ``add(widget, 'main', options)``, etc.
  * Rename ``pageUrl`` to ``appUrl`` in the server connection
  * ``MainAreaWidget`` instances now forward update requests to their ``content``
  * The theme data attributes are renamed and moved to the document body element. If you are relying on these attributes in CSS to conditionally style based on the theme, you should update their names. For example ``data-theme-light`` is now ``data-jp-theme-light``.
  * Extensions which require CSS should no longer import their CSS files into their Javascript files. Instead, they should specify a root CSS file in the ``style`` attribute in their ``package.json``, and JupyterLab will automatically import that CSS file.
  * ``Dialog.prompt`` has been replaced by a number of type-specific dialogs such as ``InputDialog.getString``, ``InputDialog.getBoolean``, etc.
  * When a ``RenderMime`` widget is re-rendered, the default behavior is to remove any existing content in the DOM. This can be overridden if needed.
  * We have updated our internal TypeScript version to 3.5.1 and our compile target to ``ES2017``. Extensions may need to upgrade their TypeScript version and target as well.
  * We have updated the typings for some of the Kernel messages so that they better match the spec.
  * A ``connectionFailure`` signal has been added to some of the manager classes, which can be used to detect when a connection to the server is lost
  * Add rate limiting and polling utilities to ``coreutils``  to use for throttling and debouncing of API requests
  * Require session when instantiating terminal widget
  * Provides a signal to see what items are opened in a directory listing
  * Ads the ability to add widget above the main work area to a top header area
  * Renames ``contextMenuFirst`` to  ``contextMenuHitTest`` in the ``JupyterFrontEnd``
  * Removes the ``initialCommand`` arg from the terminal creation command.
  * Adds ``--jp-code-cursor-width0``, ``--jp-code-cursor-width1``, and ``--jp-code-cursor-width2`` variables to the themes to support changing the cursor width if you change the font size
  * Adds the ability to insert a new item to the toolbar before or after another item
  * Adds the ability for extensions to register new CodeMirror modes
  * We have removed the ``JUPYTERLAB_xxx_LOADER`` Webpack loaders, instead you should use the loader directly in the URL as Webpack supports it
  * Adds the ability to handle fragments for document widgets
  * We have added a  ``@jupyterlab/ui-components`` package that contains reusable React components to be used internally and in extensions. Feel free to use this to create extension UIs with consistent styles
  * The ``showErrorMessage`` function now lets you customize the buttons it uses
  * We now provide helpers for using React components within JupyterLab. If you were previously using ``ReactElementWidget`` you should switch to using ``ReactWidget``.
  * The share link command has been moved to its own extension so that it can be overridden
  * Creating a new services session now requires passing a kernel model instead of a kernel instance
  * We upgraded the Webpack raw file loader. The new version of the raw loader exports ES2015 modules, so this may require changes in extensions that import files using the raw loader. For example, if you did ``require('myfile.md')`` to get the content of `myfile.md` as a string, you now should import it using ES2015 `import` syntax, or use `require('myfile.md').default`.
  * Widget factories now can support custom cloning behavior from an optional source widget
  * We have renamed the type ``InstanceTracker`` to ``WidgetTracker``.
  * In order to add widgets to the main area (e.g. as in the old XKCD extension tutorial), the correct syntax is now ``app.shell.add(widget)`` or ``app.shell.add(widget, 'main')``,
* Tue May 14 2019 Todd R <toddrme2178@gmail.com>
- Update to 0.35.6
  * Publish outputarea 0.19.2
  * Make sure the cached value of `_lastStream` reflects the removed
    characters so we don't have to remove them over and over again.
- Split directories and macros into separate package.
* Thu Apr 25 2019 Todd R <toddrme2178@gmail.com>
- Update to 0.35.5
  * use target=_blank for download links
  * Release filebrowser@0.19.4
- Rename to to match jupyter package naming guidelines.
- Add rpm macros
* Fri Jan  4 2019 Todd R <toddrme2178@gmail.com>
- Update to 0.35.4
  + Features
  * A notebook cell can now be readonly, reflecting its ``enabled`` metadata. (`#5401 <https://github.com/jupyterlab/jupyterlab/pull/5401>`__, `#1312 <https://github.com/jupyterlab/jupyterlab/issues/1312>`__)
  * Add "Go To Line" in the Edit menu for text editors. (`#5377 <https://github.com/jupyterlab/jupyterlab/pull/5377>`__)
  * Sidebar panels can now be switched between left and right sidebars. Right-click on a sidebar tab to move it to the other sidebar. (`#5347 <https://github.com/jupyterlab/jupyterlab/pull/5347>`__, `#5054 <https://github.com/jupyterlab/jupyterlab/  issues/5054>`__, `#3707 <https://github.com/jupyterlab/jupyterlab/issues/3707>`__)
  * Make the sidebar a bit narrower, and make the minimum width adjustable from a theme. (`#5245 <https://github.com/jupyterlab/jupyterlab/pull/5245>`__)
  * Populate the File, Export Notebook As... submenu from the server nbconvert capabilities. (`#5217 <https://github.com/jupyterlab/jupyterlab/pull/5217>`__)
  * Server contents managers can now tell JupyterLab to open files as notebooks. For example, several custom contents managers save and open notebooks as Markdown files. (`#5247 <https://github.com/jupyterlab/jupyterlab/pull/5247>`__, `#4924 <https://github.com/jupyterlab/jupyterlab/issues/4924>`__)
  * Add a command-line interface for managing workspaces. (`#5166 <https://github.com/jupyterlab/jupyterlab/pull/5166>`__)
  * Allow safe inline CSS styles in Markdown. (`#5012 <https://github.com/jupyterlab/jupyterlab/pull/5012>`__, `#1812 <https://github.com/jupyterlab/jupyterlab/issues/1812>`__)
  * Add Quit to File menu when appropriate. (`#5226 <https://github.com/jupyterlab/jupyterlab/pull/5226>`__, `#5252 <https://github.com/jupyterlab/jupyterlab/pull/5252>`__, `#5246 <https://github.com/jupyterlab/jupyterlab/issues/5246>`__, `#5280 <https://github.com/jupyterlab/jupyterlab/pull/5280>`__)
  * Rework extension manager user experience. (`#5147 <https://github.com/jupyterlab/jupyterlab/pull/5147>`__, `#5042 <https://github.com/jupyterlab/jupyterlab/issues/5042>`__)
  + Dark theme
  * Show a dark splash screen when using a dark theme. (`#5339 <https://github.com/jupyterlab/jupyterlab/pull/5339>`__, `#5338 <https://github.com/jupyterlab/jupyterlab/issues/5338>`__, `#5403 <https://github.com/jupyterlab/jupyterlab/pull/5403>`__)
  * Fix code completion menu for a dark theme. (`#5364 <https://github.com/jupyterlab/jupyterlab/pull/5364>`__, `#5349 <https://github.com/jupyterlab/jupyterlab/issues/5349>`__)
  * Style CSV viewer for a dark theme. (`#5304 <https://github.com/jupyterlab/jupyterlab/pull/5304>`__, `#3456 <https://github.com/jupyterlab/jupyterlab/issues/3456>`__)
  * Make Matplotlib figures legible in a dark theme. (`#5232 <https://github.com/jupyterlab/jupyterlab/pull/5232>`__)
  * Fix notebook cell dropdown legibility in a dark theme. (`#5168 <https://github.com/jupyterlab/jupyterlab/issues/5168>`__)
  + Bug fixes
  * Various save options in the file menu and toolbar are now disabled when a file is not writable. (`#5376 <https://github.com/jupyterlab/jupyterlab/pull/5376>`__, `#5391 <https://github.com/jupyterlab/jupyterlab/pull/5391>`__)
  * Kernel selector dialog no longer cuts off kernel names. (`#5260 <https://github.com/jupyterlab/jupyterlab/pull/5260>`__, `#5181 <https://github.com/jupyterlab/jupyterlab/issues/5181>`__)
  * Fix focus issues with the toolbar. (`#5344 <https://github.com/jupyterlab/jupyterlab/pull/5344>`__, `#5324 <https://github.com/jupyterlab/jupyterlab/pull/5324>`__, `#2995 <https://github.com/jupyterlab/jupyterlab/issues/2995>`__, `#5328 <https://github.com/jupyterlab/jupyterlab/pull/5328>`__)
  * Fix toolbar button enabled/disabled status. (`#5278 <https://github.com/jupyterlab/jupyterlab/pull/5278>`__)
  * Table alignment is now respected in Markdown. (`#5301 <https://github.com/jupyterlab/jupyterlab/pull/5301>`__, `#3180 <https://github.com/jupyterlab/jupyterlab/issues/3180>`__)
  * Fix syntax highlighting for Markdown lists. (`#5297 <https://github.com/jupyterlab/jupyterlab/pull/5297>`__, `#2741 <https://github.com/jupyterlab/jupyterlab/issues/2741>`__)
  * Use the current filebrowser instead of the default one for various commands. (`#5390 <https://github.com/jupyterlab/jupyterlab/pull/5390>`__)
  * Fix escaping in link handling to conform to Markdown syntax. This means that spaces in link references now need to be encoded as ``%%20``. (`#5383 <https://github.com/jupyterlab/jupyterlab/pull/5383>`__, `#5340 <https://github.com/jupyterlab/jupyterlab/pull/5340>`__, `#5153 <https://github.com/jupyterlab/jupyterlab/issues/5153>`__)
  + Build system
  * Use Typescript 3.1. (`#5360 <https://github.com/jupyterlab/jupyterlab/pull/5360>`__)
  * Use Lerna 3.2.1. (`#5262 <https://github.com/jupyterlab/jupyterlab/pull/5262>`__)
  * Node >=6.11.5 is now required. (`#5227 <https://github.com/jupyterlab/jupyterlab/pull/5227>`__)
  * Pin vega-embed version to 3.18.2. (`#5342 <https://github.com/jupyterlab/jupyterlab/pull/5342>`__)
  * Use Jest for services tests. (`#5251 <https://github.com/jupyterlab/jupyterlab/pull/5251>`__, `#5282 <https://github.com/jupyterlab/jupyterlab/pull/5282>`__)
  * Make it easier for third party extensions to use the JupyterLab test app and testing utilities. (`#5415 <https://github.com/jupyterlab/jupyterlab/pull/5415>`__)
  * Fix ``jupyter lab clean`` on Windows. (`#5400 <https://github.com/jupyterlab/jupyterlab/pull/5400>`__, `#5397 <https://github.com/jupyterlab/jupyterlab/issues/5397>`__)
  * Fix ``jupyter lab build`` on NFS. (`#5237 <https://github.com/jupyterlab/jupyterlab/pull/5237>`__, `#5233 <https://github.com/jupyterlab/jupyterlab/issues/5233>`__)
  * Build wheels for Python 3 only. (`#5287 <https://github.com/jupyterlab/jupyterlab/pull/5287>`__)
  * Migrate to using ``jupyterlab_server`` instead of ``jupyterlab_launcher`` and fix the app example. (`#5316 <https://github.com/jupyterlab/jupyterlab/pull/5316>`__)
  * Move Mathjax 2 typesetter to a library package. (`#5259 <https://github.com/jupyterlab/jupyterlab/pull/5259>`__, `#5257 <https://github.com/jupyterlab/jupyterlab/issues/5257>`__)
  + For Developers
  * Default toolbar buttons can be overridden, and mime renderers can now specify toolbar buttons. (`#5398 <https://github.com/jupyterlab/jupyterlab/pull/5398>`__, `#5370 <https://github.com/jupyterlab/jupyterlab/pull/5370>`__, `#5363 <https://github.com/jupyterlab/jupyterlab/issues/5363>`__)
  * A JupyterLab application instance can now be given a document registry, service manager, and command linker. (`#5291 <https://github.com/jupyterlab/jupyterlab/pull/5291>`__)
* Fri Sep 28 2018 Todd R <toddrme2178@gmail.com>
- Update to 0.34.12
  * add sidebar min-width css variable
  * use encodeURI instead of encodeURIComponent for shareable links
  * expand JupyterLab.IOptions to allow for custom DocumentRegistry
  * Rename package.json to package.json.orig when copying it to build folder
  * fix python versions of build wheels by removing the universal flag
  * Hide quit entry for older notebook versions
  * Notebook 4.3 Shim
* Fri Sep  7 2018 toddrme2178@gmail.com
- Update to 0.34.7
  * Notebooks, consoles, and text files now have access to completions for local
    tokens.
  * Python 3.5+ is now required to use JupyterLab. Python 2 kernels can still be
    run within JupyterLab.
  * Added the pipe (``|``) character as a CSV delimiter option.
  * Added "Open From Path..."" to top level ``File`` menu.
  * Added "Copy Download Link" to context menu for files.
* Thu Aug  2 2018 toddrme2178@gmail.com
- Update to 0.33.4
  + Key Features:
  * No longer in beta
  * Workspaces
  * Menu items
  * Keyboard shortcuts
  * Command palette items
  * Settings
  * Larger file uploads
  * Extension management and installation
  * Interface changes
  * Renderers
  * Changes for developers
  * Other fixes
* Wed May  2 2018 jengelh@inai.de
- Trim filler wording from description.
- Replace bashisms in %%install.
* Thu Apr 19 2018 toddrme2178@gmail.com
- Update to version 0.32.0
  * Better handling of a corrupted or invalid state database ([#3619](https://github.com/jupyterlab/jupyterlab/issues/3619), [#3622](https://github.com/jupyterlab/jupyterlab/issues/3622), [#3687](https://github.com/jupyterlab/jupyterlab/issues/3687), [#4114](https://github.com/jupyterlab/jupyterlab/issues/4114)).
  * Fixing file dirty status indicator ([#3652](https://github.com/jupyterlab/jupyterlab/issues/3652)).
  * New option for whether to autosave documents ([#3734](https://github.com/jupyterlab/jupyterlab/issues/3734)).
  * More commands in the notebook context menu ([#3770](https://github.com/jupyterlab/jupyterlab/issues/3770), [#3909](https://github.com/jupyterlab/jupyterlab/issues/3909))
  * Defensively checking for completion metadata from kernels ([#3888](https://github.com/jupyterlab/jupyterlab/issues/3888))
  * New "Shutdown all" button  in the Running panel ([#3764](https://github.com/jupyterlab/jupyterlab/issues/3764))
  * Performance improvements wherein non-focused documents poll the server less ([#3931](https://github.com/jupyterlab/jupyterlab/issues/3931))
  * Changing the keyboard shortcut for singled-document-mode to something less easy to trigger ([#3889](https://github.com/jupyterlab/jupyterlab/issues/3889))
  * Performance improvements for rendering text streams, especially around progress bars ([#4045](https://github.com/jupyterlab/jupyterlab/issues/4045)).
  * Canceling a "Restart Kernel" now functions correctly ([#3703](https://github.com/jupyterlab/jupyterlab/issues/3703)).
  * Defer loading file contents until after the application has been restored ([#4087](https://github.com/jupyterlab/jupyterlab/issues/4087)).
  * Ability to rotate, flip, and invert images in the image viewer ([#4000](https://github.com/jupyterlab/jupyterlab/issues/4000))
  * Major performance improvements for large CSV viewing ([#3997](https://github.com/jupyterlab/jupyterlab/issues/3997)).
  * Always show the context menu in the file browser, even for an empty directory ([#4264](https://github.com/jupyterlab/jupyterlab/issues/4264)).
  * Handle asynchronous comm messages in the services library more correctly (Note: this means `@jupyterlab/services` is now at version 2.0!) ([[#4115](https://github.com/jupyterlab/jupyterlab/issues/4115)](https://github.com/jupyterlab/jupyterlab/pull/4115)).
  * Display the kernel banner in the console when a kernel is restarted to mark the restart ([[#3663](https://github.com/jupyterlab/jupyterlab/issues/3663)](https://github.com/jupyterlab/jupyterlab/pull/3663)).
  * Many tweaks to the UI, as well as better error handling.
* Mon Mar 12 2018 toddrme2178@gmail.com
- Bugfixes.
- Update summary and description
- Package other version of extensions directory.
* Wed Feb 28 2018 toddrme2178@gmail.com
- Package extensions directory.
* Thu Nov 16 2017 toddrme2178@gmail.com
- Initial version
